## How to use

### Initialize a project

    poetry init

### Install webint

    poetry add webint

### Create your website

    poetry run web scaffold

### Run your website

    poetry run web run 9999

### Open your website

    open http://localhost:9999

### Modify your website

    ...

### Deploy your website

#### On a cloud server only

#### On a home server through a cloud server (for TLS termination)

#### On a home server only (via tor)
